@@ -1,6 +1,6 @@
 package App::PrereqGrapher;
 {
-  $App::PrereqGrapher::VERSION = '0.09';
+  $App::PrereqGrapher::VERSION = '0.10';
 }
 #
 # ABSTRACT: generate dependency graph using Perl::PrereqScanner
@@ -164,7 +164,7 @@ sub generate_graph
         croak "Failed to write $filename: $!\n";
     print $fh $formats{$self->format}->($graph);
     close($fh);
-    print STDERR "$module_count modules processed. Graph written to $filename\n";
+    print STDERR "$module_count modules processed. Graph written to $filename\n" if $self->verbose;
 }
 
 sub is_core
